@@ -3,7 +3,7 @@ package App::MediaInfo;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-30'; # DATE
 our $DIST = 'App-MediaInfo'; # DIST
-our $VERSION = '0.125'; # VERSION
+our $VERSION = '0.126'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,23 +22,19 @@ $SPEC{':package'} = {
 our %arg0_media_multiple = (
     media => {
         summary => 'Media files/URLs',
-        schema => ['array*' => of => 'str*'],
+        schema => ['array*' => of => 'filename*'], # XXX filename_or_url
         req => 1,
         pos => 0,
         greedy => 1,
-        #'x.schema.entity' => 'filename_or_url',
-        'x.schema.entity' => 'filename', # temp
     },
 );
 
 our %arg0_media_single = (
     media => {
         summary => 'Media file/URL',
-        schema => ['str*'],
+        schema => ['filename*'], # XXX filename_or_url
         req => 1,
         pos => 0,
-        #'x.schema.entity' => 'filename_or_url',
-        'x.schema.entity' => 'filename', # temp
     },
 );
 
@@ -256,7 +252,7 @@ App::MediaInfo - Utilities related to getting (metadata) information from media
 
 =head1 VERSION
 
-This document describes version 0.125 of App::MediaInfo (from Perl distribution App-MediaInfo), released on 2020-05-30.
+This document describes version 0.126 of App::MediaInfo (from Perl distribution App-MediaInfo), released on 2020-05-30.
 
 =head1 FUNCTIONS
 
@@ -290,7 +286,7 @@ Arguments ('*' denotes required arguments):
 
 Choose a specific backend.
 
-=item * B<media>* => I<array[str]>
+=item * B<media>* => I<array[filename]>
 
 Media filesE<sol>URLs.
 
@@ -331,7 +327,7 @@ Arguments ('*' denotes required arguments):
 
 Choose a specific backend.
 
-=item * B<media>* => I<str>
+=item * B<media>* => I<filename>
 
 Media fileE<sol>URL.
 
@@ -376,7 +372,7 @@ Arguments ('*' denotes required arguments):
 
 Choose a specific backend.
 
-=item * B<media>* => I<str>
+=item * B<media>* => I<filename>
 
 Media fileE<sol>URL.
 
@@ -421,7 +417,7 @@ Arguments ('*' denotes required arguments):
 
 Choose a specific backend.
 
-=item * B<media>* => I<str>
+=item * B<media>* => I<filename>
 
 Media fileE<sol>URL.
 
